#
# spec file for package geoclue2
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name geoclue
%define dbus_user srvGeoClue
Name:           geoclue2
Version:        2.4.3
Release:        4.3
Summary:        GeoLocation Framework
License:        GPL-2.0+
Group:          System/Libraries
Url:            http://people.freedesktop.org/~zeenix/releases/
Source:         http://www.freedesktop.org/software/geoclue/releases/2.4/%{_name}-%{version}.tar.xz
Source99:       geoclue2-rpmlintrc
# PATCH-FIX-UPSTREAM geoclue2-permit-gnome-maps.patch dimstar@opensuse.org -- Allow gnome-maps to access geoclue
Patch0:         geoclue2-permit-gnome-maps.patch
BuildRequires:  gtk-doc
BuildRequires:  intltool >= 0.40.0
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  perl(XML::Parser)
BuildRequires:  pkgconfig(avahi-client) >= 0.6.10
BuildRequires:  pkgconfig(avahi-glib) >= 0.6.10
BuildRequires:  pkgconfig(gio-2.0) >= 2.34.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.34.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.34.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.14
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.42
BuildRequires:  pkgconfig(mm-glib) >= 1.0
BuildRequires:  pkgconfig(systemd)
# we require shadow for useradd
Requires(pre):  shadow
# Virtual provides for the dbus service
Provides:       dbus(org.freedesktop.GeoClue2) = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

%description
GeoClue is a software framework which can be used to enable geospatial
awareness in applications. GeoClue uses the D-Bus inter-process
communication mechanism to provide location information

%package -n typelib-1_0-Geoclue-2_0
Summary:        GeoLocation Framework --GObject Introspection
Group:          System/Libraries

%description -n typelib-1_0-Geoclue-2_0
GeoClue is a software framework which can be used to enable geospatial
awareness in applications. GeoClue uses the D-Bus inter-process
communication mechanism to provide location information

%package devel
Summary:        GeoLocation Framework -- Development files
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}
Requires:       typelib-1_0-Geoclue-2_0 = %{version}

%description devel
GeoClue is a software framework which can be used to enable geospatial
awareness in applications. GeoClue uses the D-Bus inter-process
communication mechanism to provide location information

%prep
%setup -q -n %{_name}-%{version}
%patch0 -p1

%build
%configure \
    --disable-geoip-server \
    --enable-introspection \
    --with-dbus-service-user=%{dbus_user}
make %{?_smp_mflags} V=1

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
install -d %{buildroot}%{_localstatedir}/lib/%{dbus_user}
# Create conveniance shortcut for rcgeoclue -> /usr/sbin/service
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcgeoclue
find %{buildroot} -type f -name "*.la" -delete -print
# Remove desktop file, we do not build the demos
find %{buildroot} -type f -name "geoclue-demo-agent.desktop" -delete -print

%pre
getent passwd %{dbus_user} > /dev/null || useradd -r -g nogroup -d %{_localstatedir}/lib/%{dbus_user} -s /sbin/nologin -c "User for GeoClue D-Bus service" %{dbus_user}

# note: do not use systemd macros for geoclue2.service, they are not meant for dbus unit files.

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README COPYING
# Not split per SLPP as the interface to the underlying daemon is
# too strict to allow parallel installations
%{_libdir}/libgeoclue-2.so.*
%{_libexecdir}/geoclue
%dir %{_libexecdir}/geoclue-2.0/
%{_libexecdir}/geoclue-2.0/demos/
%{_datadir}/applications/geoclue-where-am-i.desktop
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/interfaces
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.Client.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.Location.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.Manager.xml
%dir %{_datadir}/dbus-1/system-services
%{_datadir}/dbus-1/system-services/org.freedesktop.GeoClue2.service
%dir %{_sysconfdir}/dbus-1
%dir %{_sysconfdir}/dbus-1/system.d
%dir %{_sysconfdir}/geoclue/
%config %{_sysconfdir}/geoclue/geoclue.conf
%config %{_sysconfdir}/dbus-1/system.d/org.freedesktop.GeoClue2.conf
%config %{_sysconfdir}/dbus-1/system.d/org.freedesktop.GeoClue2.Agent.conf
%attr(0700,%{dbus_user},root) %{_localstatedir}/lib/%{dbus_user}
%{_sbindir}/rcgeoclue
%{_unitdir}/geoclue.service

%files -n typelib-1_0-Geoclue-2_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/Geoclue-2.0.typelib

%files devel
%defattr(-,root,root)
%doc README COPYING
%{_includedir}/libgeoclue-2.0/
%{_libdir}/*.so
%{_libdir}/pkgconfig/geoclue-2.0.pc
%{_libdir}/pkgconfig/libgeoclue-2.0.pc
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.Agent.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.xml
%{_datadir}/gir-1.0/Geoclue-2.0.gir

%changelog
* Mon May 30 2016 zaitor@opensuse.org
- Add geoclue2-rpmlintrc to sources to filter out bogus rpmlint
  warning about missing systemd-service and nonstandard user.
- Add missing post/postun handling of library.
- Remove useless desktop file for demos, we do not build the demos.
* Mon May 30 2016 fcrozat@suse.com
- Do not use systemd macros for geoclue2.service, they are not
  designed for dbus systemd unit file [bsc#982216].
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Thu Mar  3 2016 zaitor@opensuse.org
- Update to version 2.4.3:
  + Fix a crash in the helper library.
* Sat Feb 27 2016 zaitor@opensuse.org
- Update to version 2.4.2:
  + Reliable desktop ID detection for xdg-app. This together with
    latest gnome-shell and gnome-control-center, allows for
    per-application geolocation access controls.
  + Don't require xdg-app applications to pass a valid desktop ID
    since Geoclue can automatically detect it.
  + Don't allow xdg-app application to become user-authorization
    agents.
  + Correct introspection namespace version for libgeoclue.
  + Option to disable the backend build.
  + Demo: Provide reason to access location data.
  + Demo agent:
  - Critical log message on failing to show notification.
  - If app provides a reason string in it's desktop file, show
    that to the user.
* Wed Dec 23 2015 dimstar@opensuse.org
- Enable GObject introspection (required by gnome-weather 3.19+):
  + Pass --enable-introspection to configure.
  + Add pkgconfig(gobject-introspection-1.0) BuildRequires.
  + Split typelib-1_0-Geoclue-2_0 subpackage.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 2.4.0:
  + Add a convenience library to make interacting with Geoclue very
    easy.
  + Put each D-Bus interface description in it's own file. Unified
    interface file still provided for backwards compatibility.
* Thu Nov  5 2015 zaitor@opensuse.org
- Correct geoclue2-permit-gnome-maps.patch to include system=false,
  all services are supposed to have a system section. Fixes
  (boo#953865).
* Mon Sep 28 2015 mpluskal@suse.com
- Update to 2.3.0
  * Add a network NMEA source, which together with this application:
    https://wiki.gnome.org/Apps/GeoclueShare allows you to use the
    GPS of your Android device on your geoclue-enabled machine.
  * Allow root to own the name on the bus, i-e run the service.
  * Make use of compass device if available, through iio-proxy.
  * Fix a hang on client starting twice.
  * More helpful error on agent rejection.
  * Improved documentation.
  * Do not ship generated D-Bus service files in the tarball.
  * Only allow the geoclue user and root to call methods on agents.
  * Fix ignoring of valid location updates due to comparison of
    stances in different units.
  * Correctly handle two consecutive location updates with same
    mestamp on them.
  * Correctly handle late location update.
  * Build system fixes:
    + Fix detection of gdbus-codegen tool.
    + Workaround an intltool issue.
- Update dependencies
- Make build more verbose
* Sat Apr 11 2015 zaitor@opensuse.org
- Update to version 2.2.0:
  + Report 'Speed' and 'Heading' on location updates.
  + Try to provide the most accurate location first.
  + Avoid a crash by ensuring requested max accuracy is within
    bounds.
  + Fix GPS coordinates parsing.
  + Fix GeoIP on machines without WiFi hardware.
  + Gracefully handle inexistent agent.
  + Stop sources whose accuracy level becomes higher, rather than
    lower, than the requested level.
  + Keep old location object alive on D-Bus for a bit longer to
    ensure applications are not accessing it still after it is
    destroyed.
  + Don't enable the modem. Seems at least GNOME takes care of
    modem enabling for us and besides this shouldn't be done by
    geoclue anyway (fdo#85040).
  + Wait for modem to be enabled before checking availability of
    location capabilities and using them. This is particularly
    important for pin-enabled modems.
  + Ignore redundant GPS location updates.
  + Fix some potential crashes.
  + Some improvements to output of where-am-i demo application.
* Thu Feb 12 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update dependencies
- Do not try to remove .la files
* Sat Oct  4 2014 dimstar@opensuse.org
- Update to version 2.1.10:
  + Disallow application if disabled explicitly in the
    configuration.
  + Make it easy to add alternative modem source(s), e.g
    ofono-based.
  + Map:
  - country-level accuracy to city-level since no source provides
    country-level accuracy.
  - neighborhood-level accuracy to city-level in WiFi source
    (only) so applications requesting neighborhood-level accuracy
    still get a location even if there is no modem available.
  + Fixes to WiFi source.
  + For easier debugging, add:
  - more debug prints.
  - commandline options to where-am-i demo application to specify
    timeout and requested accuracy level.
  + Fix a potential build failure.
* Thu Aug  7 2014 dimstar@opensuse.org
- Update to version 2.1.9:
  + Move from NetworkManager to direct use of wpa_supplicant to
    retreive WiFI data, for greater portability.
  + Port from opencellid.org to Mozilla Location Service for
    3G-geolocation.
  + Network data submission
  - Explicit option in config to enable submission.
  - Commandline options to enable network data submission and set
    nickname.
  - Submit 3G data.
  - Submit under 'geoclue' nick by default.
  + Fix a few crashes.
  + Drop now redundant workaround for pure geoip queries.
  + Ability to mark an app as system component in the config so
    that:
  - Agent can't decide its accuracy level nor agent is asked to
    authorize it. This mean automatic timezone in GNOME will
    continue working even if you disable geolocation.
  - App is not taken into account for 'InUse' property. That
    means you will no longer have to see location crosshair in
    gnome-shell's topbar forever just because you have automatic
    timezone enabled.
  + Exit demo app if geoclue deactivates it.
  + Improved debug log.
  + Many other internal changes and minor improvements.
- Changes from version 2.1.8:
  + Switch to Mozilla Location Service for geoip as well.
  + Allow specifying nickname to submit network data with.
  + Report actual available accuracy level and keep it up2date.
  + Add 'Active' property to indicate client state.
  + Expose altitude info (if known).
  + Timeout on inactivity, rather than no clients.
  + Automatically:
  - stop the client if max accuracy level is set to 0.
  - start the client if max accuracy level is set to non-0 and it
    was automatically stopped.
  + Don't disable modem after using it. Disabling the modem,
    disables it for everyone so if there was an active connection
    going on through the modem, geoclue will cause it to
    disconnect. While we need to have some centralized means to
    enable/disable modem and ideally geoclue shouldn't do any
    enabling/disabling of modems at all, for now lets just only
    enable the modem.
  + Fix issue of missed location updates.
  + Whitelist correct ID for gnome-settings-daemon in default
    config.
  + Replace '--disable-wifi-source' configure option with
    '--disable-network-manager'. i-e now you disable usage of
    NetworkManger explicitly rather than wifi source, which is now
    always built and enabled.
  + Drop now redundant geoip server.
  + Don't distribute .desktop.in files for demos.
  + Plug some leaks.
  + More debug log.
  + Other minor fixes.
- Changes from version 2.1.7:
  + 'InUse' property now only affected by active clients. This
    fixes the issue of gnome-shell incorrectly showing 'geolocation
    in use' icon.
  + Move DBus interface files to their canonical location:
    /usr/share/dbus-1/interfaces/.
  + Drop redundant check for the C++ compiler in configure script.
  + Demo agent now prints 'geolocation in use' info.
- Drop pkgconfig(libnm-glib) and pkgconfig(libxml-2.0)
  BuildRequires: no longer needed.
- Add geoclue2-permit-gnome-maps.patch: Allow gnome-maps to access
  geoclue.
- Also drop the invalid rpmlintrc variant geoclue2.rpmlintrc.
* Sat Apr  5 2014 dimstar@opensuse.org
- Actually drop the rpmlintrc: the dbus service has been
  authorized.
* Fri Apr  4 2014 adrian@suse.de
- use addFilter instead of setBadness
* Thu Mar 13 2014 zaitor@opensuse.org
- Update to version 2.1.6:
  + Correct binary path is demo's desktop file.
  + Move demo apps from /usr/share to /usr/libexec.
- Changes from version 2.1.5:
  + Add a NULL check to fix a crasher.
  + Setup D-Bus policy to be able to access NetworManager API.
  + Expected agent object path now static. This breaks agent
    interface but it was needed to fix the D-Bus policy.
  + Fix issue of us giving every connection access to every
    property on the system bus.
- Changes from version 2.1.4:
  + Don't depend on unreleased libnm-glib.
- No longer use sed to lower libnm-glib requirement, fixed
  upstream.
* Sun Feb 23 2014 zaitor@opensuse.org
- Add pkgconfig(systemd) BuildRequires and add relevant
  systemdmacros to pre/post/preun/postun.
- Create softlink /usr/sbin/rcgeoclue to /usr/sbin/service.
* Fri Feb 21 2014 zaitor@opensuse.org
- Update to version 2.1.3:
  + Agents can now dictate maximum accuracy level allowed for all
    clients through a D-Bus property. The next version of
    gnome-shell will make use of that and provide an option to
    enable/disable geolocation in topbar menu.
  + Add D-Bus property to specify available accuracy level. For now
    we just hardcode it to report that we can provide exact
    accuracy.
  + Give agents time to register themselves on startup before
    processing client requests.
  + Move configuration file under geoclue subdir so that in future
    we can easily add more configuration files if needed.
  + Fixes to build.
  + Some internal clean-ups.
* Tue Feb  4 2014 zaitor@opensuse.org
- Update to version 2.1.2:
  + Fix some crashing bugs.
  + Ignore WiFis with '_nomap' suffix.
  + Configure options for disabling WiFi, 3G and GPS modem sources.
  + Avoid spaming the network resources for ignorable changes to
    network setup.
  + Add some required files to distribution that we forgot in last
    release.
- Changes from version 2.1.1:
  + 3GPP-based geolocation source.
  + Uses ModemManager to get cell tower info from 3GPP modem and
    uses opencellid.org's public API to translate that into a
    location.
  + GPS modem-based geolocation source: If your 3GPP modem has a
    GPS, geoclue can now make use of it.
  + WiFi-based geolocation source.
  + Uses Mozilla Location Service to find location based on nearby
    WiFi networks.
  + Refresh location on changes in WiFi networks.
  + Option in configuration file to make geoclue use Google Maps
    Geolocation API rather than Mozilla Location Service.
  + Option in configuration file to enable submission of wifi data
    to Mozilla Location Service. If this option is enabled, the
    data is submitted each time geoclue gets a GPS lock. That
    means, its not completely autonomous and data is only
    submitted if an application, e.g gnome-maps requests current
    location with exact accuracy.
  + API for clients to specify what level of geolocation accuracy
    they need, e.g city-level, street-level or exact etc.
  + API to check if geolocation service is in use. Next version of
    gnome-shell will make use of that to show an icon in the panel
    to indicate to user that their location is being accessed.
  + Application authorization agent.
  + Make agent completely optional. We will revert this once we
    have a reliable mechanism to identify applications.
  + Identify agent and client applications by their desktop IDs
    rather than paths of their binaries.
  + Ability for agents to dictate the accuracy level allowed for
    clients.
  + Maintain a whitelist of clients in configuration that do not
    need agent authorization.
  + Avoid redundant queries to web services.
  + Install demo applications and provide a desktop file for them.
  + Many more internal fixes and clean-ups.
- Add pkgconfig(libnm-glib), pkgconfig(mm-glib) and
  pkgconfig(libxml-2.0) BuildRequires: new dependencies.
- Lower NetworkManager dependency to 0.9.8 in configure.
* Sun Jan 19 2014 zaitor@opensuse.org
- Update to version 2.1.0:
  + Application authentication agents support:
  - API for agents to register themselves.
  - API that agents need to implement.
  - Configure option to enable requirement of authorization from
    agent. Until there is at least one agent out there, this
    requirement is disabled by default.
  - A demo agent.
  - Option in ${sysconfdir}/geoclue.conf containing whitelist of
    all our agents.
  + Don't use proxy. Seems proxy settings are per-user and system
    users (which geoclue is supposed to run as) do not have access
    to them.
  + Add support for bus-activation via systemd service unit.
  + Add mandatory 'DesktopId' property to Client interface.
  + Use HTTPS to connect to geoip.fedoraproject.org. The actual
    resource is behind HTTPS so using HTTP leads to redirections
    and thefore redundant TCP packets.
  + Fixes to build system.
* Mon Oct  7 2013 dimstar@opensuse.org
- Create and package %%{_localstatedir}/lib/%%{dbus_user} (the dbus
  user's home directory).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 2.0.0:
  + Generate docs for D-Bus interface.
  + Fix build against Automake 1.13.
  + Two minor fixes/cleanups.
- Changes from version 1.99.4:
  + Correct check for whether db needs update in geoip-update.
  + Fix geoip-update by direct usage of libsoup for HTTP GET.
  + Don't inhibit compiler warnings in build.
  + Fix various potential crashers.
  + Take 'DistanceThreshold' property into account.
  + Watch for and signal out location changes.
  + Add configure option to specify service user.
  + Add documentation comments to D-Bus interface XML.
  + Fix various compiler warnings.
  + Switch to Fedora's geoip server until we've our server setup.
  + Minor fixes to pkgconfig file.
  + Setup a glib log domain.
  + Some optimizations.
  + More debug logging.
- Drop geoclue2-no-root.patch: fixed upstream.
- Drop libtool BuildRequires and call to autoreconf, as we do no
  longer carry any patch requiring to bootstrap.
* Sun Sep 15 2013 dimstar@opensuse.org
- Provide dbus(org.freedesktop.GeoClue2) instead of dbus(GeoClue2),
  as this is much closer to reality.
* Wed Sep 11 2013 dimstar@opensuse.org
- Re-enable the D-Bus service, as the services have been white-
  listed for Factory.
* Tue Sep 10 2013 dimstar@opensuse.org
- Add COPYING to the package as %%doc.
* Mon Sep  9 2013 dimstar@opensuse.org
- Do not package the D-Bus service for now. This makes the package
  'broken', but allows us to build against the D-Bus interface and
  not block inclusion of other packages any furhter (bnc#838360).
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 1.99.3:
  + All D-Bus prop names capitalized as per general conventions.
  + Expose D-Bus specification XML file in pkg-config file.
  + Fix some potential crashes in error handling code.
  + Remove unused build-time yelp dependency.
  + Correct the libsoup dependency in pkg-config (although it
    doesn't affect any applications at the moment).
  + Fix some compiler warnings.
- Changes from version 1.99.2:
  + Drop client-side library.
  + Add COPYING file.
  + Install geoip-lookup with make install. This makes life easier
    for binary distributions that can then ship geoip-lookup in a
    package.
  + Distribute server documentation.
  + Distribute & install interface XML file.
  + Add/update forgotten copyright headers.
- Changes from version 1.99.1:
  + Move to system D-Bus.
  + Import geoip code from geocode-glib.
  + Add option to automatically exit on inactivity. By default it:
  - Runs indefinitely when launched manually.
  - Exits after 5 seconds of inactivity when (auto)launched by
    D-Bus.
  + Relicense from LGPLv2+ to GPLv2+.
  + Some build/installation related fixes.
  + Correctly version pkg-config file.
  + Fix crash on error.
  + Add --version cmdline option.
- Changes from version 1.99.0:
  + Bump the version number.
- Drop typelib-1_0-GeoClue-1_0 and libgeoclue-1_0-0 subpackages:
  the client-side library was dropped with version 1.99.2.
- Add geoclue2-no-root.patch: Add configure option to specify
  service user.
- Add call to autoreconf in build phase, as above patch touches
  the buildsystem.
- Define dbus_user: srvGeoClue.
- Pass --with-dbus-service-user=%%{dbus_user} to configure.
- Create %%dbus_user during pre phase if the user does not yet
  exist.
* Mon Aug  5 2013 dimstar@opensuse.org
- Add ldconfig call to post/postun.
* Mon Aug  5 2013 dimstar@opensuse.org
- Initial package, version 0.0.1.
